import { listen } from "@tauri-apps/api/event";
import { getCurrentWindow } from "@tauri-apps/api/window";
import { type Component, createEffect } from "solid-js";
import { sendImage } from "../network";

type ImageViewerProps = {
    onSendImage: (
        processingImage: Awaited<ReturnType<typeof sendImage>>,
    ) => void;
};

export const ImageViewer: Component<ImageViewerProps> = (props) => {
    // const [latestImage, setLatestImage] = createSignal<string | null>(null);

    createEffect(async () => {
        // Listen for PNG processing events
        const unlisten = listen("png-processed", async (event) => {
            console.log("Received processed PNG", event);
            const base64Data = event.payload as string;

            const appWindow = getCurrentWindow();

            appWindow.show();
            appWindow.setFocus();

            // setLatestImage(`data:image/png;base64,${base64Data}`);

            const result = await sendImage("test-image.png", base64Data);

            props.onSendImage(result);

            console.log("DBG: ", result);
        });

        return () => {
            unlisten.then((fn) => fn()); // Cleanup listener
        };
    });

    return null;

    // return (
    //     <div class="fixed inset-0">
    //         {latestImage() && (
    //             <div class="mt-4">
    //                 <h3>Latest Processed Image:</h3>
    //                 <img
    //                     src={latestImage() || undefined}
    //                     alt="Latest processed"
    //                     class="max-w-md"
    //                 />
    //             </div>
    //         )}
    //     </div>
    // );
};
