import { createEffect, Show, type Accessor, type Component } from "solid-js";
import { base, type sendImage } from "../../network";
import { useSearchImageContext } from "../../contexts/SearchImageContext";

type ImageStatusProps = {
    onSetProcessingImage: (
        image: Awaited<ReturnType<typeof sendImage>> | undefined,
    ) => void;
    processingImage: Accessor<
        Awaited<ReturnType<typeof sendImage>> | undefined
    >;
};

type EventData = "in-progress" | "complete";

export const ImageStatus: Component<ImageStatusProps> = (props) => {
    const { onRefetchImages } = useSearchImageContext();

    const onEvent = (e: MessageEvent<EventData>) => {
        console.log(e.data);

        const processingImage = props.processingImage();
        if (processingImage == null) {
            throw new Error("Processing Image should not be null");
        }

        if (e.data !== "complete") {
            props.onSetProcessingImage({
                ...processingImage,
                Status: e.data,
            });

            return;
        }

        props.onSetProcessingImage(undefined);
        onRefetchImages();
    };

    createEffect(() => {
        const image = props.processingImage();
        if (image == null) {
            return;
        }

        const eventSourceUrl = `${base}/image-events/${image.ID}`;

        const eventSource = new EventSource(eventSourceUrl);
        console.log("URL: ", eventSourceUrl);

        eventSource.addEventListener("data", onEvent);

        return () => {
            eventSource.removeEventListener("data", onEvent);
        };
    });

    return (
        <Show when={props.processingImage()}>
            {(image) => (
                <div>
                    <p>
                        {image().ImageID} - {image().Status}
                    </p>
                </div>
            )}
        </Show>
    );
};
